/*
 * CDAccount.java
 *
 */
import java.util.*;

public class CDAccount extends Account {

	public static final int	TERM = 30;

	long	dateOfCreation; // the day when this account is created

  public CDAccount( String owner )
  {
    this(owner,0.0);
  }

  public CDAccount( String owner, double balance )
  {
    super( owner, balance );
    dateOfCreation = today();
  }

  public double withdraw( double amount )
  {
    return allowTransaction() ? super.withdraw(amount) : 0;
  }

  public double deposit( double amount )
  {
    return allowTransaction() ? super.deposit(amount) : 0;
  }

  private long today()
  {
    return System.currentTimeMillis() / 1000 / 3600 / 24;
  }

  private boolean allowTransaction()
  {
    long d = today() - dateOfCreation;
    return  d > TERM && d % TERM > 0 && d % TERM <= 7 ? true : false;
  }
 
  // overrides the toString method in Account
  public String toString()
  {
    String s = super.toString();
    s += "\n\tDate of Creation:\t" + dateOfCreation +
         "\n\tCurrent date:\t" + today();
    return s;
  }

} // end of class CDAccount

